diff --git a/hadoop-common-project/hadoop-common/src/site/apt/CommandsManual.apt.vm b/hadoop-common-project/hadoop-common/src/site/apt/CommandsManual.apt.vm
index a03dd030ca3..1608691097a 100644
--- a/hadoop-common-project/hadoop-common/src/site/apt/CommandsManual.apt.vm
+++ b/hadoop-common-project/hadoop-common/src/site/apt/CommandsManual.apt.vm
@@ -56,7 +56,7 @@ Generic Options
*------------------------------------------------+-----------------------------+
|<<<-D \=\ >>> | Use value for given property.
*------------------------------------------------+-----------------------------+
-|<<<-jt \ or \ >>> | Specify a job tracker.
+|<<<-jt \ or \>>> | Specify a ResourceManager.
| Applies only to job.
*------------------------------------------------+-----------------------------+
|<<<-files \ >>> | Specify comma separated files
diff --git a/hadoop-mapreduce-project/CHANGES.txt b/hadoop-mapreduce-project/CHANGES.txt
index 3faf511a611..6c9685ca3e8 100644
--- a/hadoop-mapreduce-project/CHANGES.txt
+++ b/hadoop-mapreduce-project/CHANGES.txt
@@ -387,6 +387,9 @@ Release 2.6.0 - UNRELEASED
MAPREDUCE-5796. Use current version of the archive name in
DistributedCacheDeploy document (Akira AJISAKA via aw)
+ MAPREDUCE-5945. Update the description of GenericOptionsParser -jt
+ option (Akira AJISAKA via aw)
+
Release 2.5.1 - 2014-09-05
INCOMPATIBLE CHANGES
diff --git a/hadoop-mapreduce-project/hadoop-mapreduce-client/hadoop-mapreduce-client-jobclient/src/test/java/org/apache/hadoop/mapred/pipes/TestPipeApplication.java b/hadoop-mapreduce-project/hadoop-mapreduce-client/hadoop-mapreduce-client-jobclient/src/test/java/org/apache/hadoop/mapred/pipes/TestPipeApplication.java
index f447ebcc7c9..c2a990eec14 100644
--- a/hadoop-mapreduce-project/hadoop-mapreduce-client/hadoop-mapreduce-client-jobclient/src/test/java/org/apache/hadoop/mapred/pipes/TestPipeApplication.java
+++ b/hadoop-mapreduce-project/hadoop-mapreduce-client/hadoop-mapreduce-client-jobclient/src/test/java/org/apache/hadoop/mapred/pipes/TestPipeApplication.java
@@ -308,7 +308,7 @@ public void testSubmitter() throws Exception {
assertTrue(out.toString().contains(
"-fs specify a namenode"));
assertTrue(out.toString().contains(
- "-jt specify a job tracker"));
+ "-jt specify a ResourceManager"));
assertTrue(out
.toString()
.contains(
diff --git a/hadoop-common-project/hadoop-common/src/main/java/org/apache/hadoop/util/GenericOptionsParser.java b/hadoop-common-project/hadoop-common/src/main/java/org/apache/hadoop/util/GenericOptionsParser.java
index 2a37dac460d..d0e765529c7 100644
--- a/hadoop-common-project/hadoop-common/src/main/java/org/apache/hadoop/util/GenericOptionsParser.java
+++ b/hadoop-common-project/hadoop-common/src/main/java/org/apache/hadoop/util/GenericOptionsParser.java
@@ -49,9 +49,9 @@
* GenericOptionsParser
is a utility to parse command line
* arguments generic to the Hadoop framework.
*
- * GenericOptionsParser
recognizes several standarad command
+ * GenericOptionsParser
recognizes several standard command
* line arguments, enabling applications to easily specify a namenode, a
* jobtracker, additional configuration resources etc.
*
*
Generic Options
*
@@ -60,7 +60,7 @@
* -conf <configuration file> specify a configuration file
* -D <property=value> use value for given property
* -fs <local|namenode:port> specify a namenode
- * -jt <local|jobtracker:port> specify a job tracker
+ * -jt <local|resourcemanager:port> specify a ResourceManager
* -files <comma separated list of files> specify comma separated
* files to be copied to the map reduce cluster
* -libjars <comma separated list of jars> specify comma separated
@@ -90,13 +90,13 @@
*
* $ bin/hadoop dfs -conf core-site.xml -conf hdfs-site.xml -ls /data
* list /data directory in dfs with multiple conf files specified.
*
* $ bin/hadoop job -D mapred.job.tracker=darwin:50020 -submit job.xml
* submit a job to job tracker darwin:50020
*
* $ bin/hadoop job -jt darwin:50020 -submit job.xml
* submit a job to job tracker darwin:50020
*
* $ bin/hadoop job -jt local -submit job.xml
* submit a job to local runner
*
@@ -213,9 +213,9 @@ private static Options buildGeneralOptions(Options opts) {
.hasArg()
.withDescription("specify a namenode")
.create("fs");
- Option jt = OptionBuilder.withArgName("local|jobtracker:port")
+ Option jt = OptionBuilder.withArgName("local|resourcemanager:port")
.hasArg()
- .withDescription("specify a job tracker")
+ .withDescription("specify a ResourceManager")
.create("jt");
Option oconf = OptionBuilder.withArgName("configuration file")
.hasArg()
@@ -408,7 +408,7 @@ private String validateFiles(String files, Configuration conf)
else {
// check if the file exists in this file system
// we need to recreate this filesystem object to copy
// these files to the file system jobtracker is running
// on.
FileSystem fs = path.getFileSystem(conf);
if (!fs.exists(path)) {
@@ -502,7 +502,7 @@ public static void printGenericCommandUsage(PrintStream out) {
out.println("-conf specify an application configuration file");
out.println("-D use value for given property");
out.println("-fs specify a namenode");
- out.println("-jt specify a job tracker");
+ out.println("-jt specify a ResourceManager");
out.println("-files " +
"specify comma separated files to be copied to the map reduce cluster");
out.println("-libjars " +
@@ -49,9 +49,9 @@
recognizes several standard command
* line arguments, enabling applications to easily specify a namenode, a
- * jobtracker, additional configuration resources etc.
+ * ResourceManager, additional configuration resources etc.
*
*
@@ -90,13 +90,13 @@
* $ bin/hadoop dfs -conf core-site.xml -conf hdfs-site.xml -ls /data
* list /data directory in dfs with multiple conf files specified.
- *
- * $ bin/hadoop job -D mapred.job.tracker=darwin:50020 -submit job.xml
- * submit a job to job tracker darwin:50020
- *
- * $ bin/hadoop job -jt darwin:50020 -submit job.xml
- * submit a job to job tracker darwin:50020
- *
+ *
+ * $ bin/hadoop job -D yarn.resourcemanager.address=darwin:8032 -submit job.xml
+ * submit a job to ResourceManager darwin:8032
+ *
+ * $ bin/hadoop job -jt darwin:8032 -submit job.xml
+ * submit a job to ResourceManager darwin:8032
+ *
* $ bin/hadoop job -jt local -submit job.xml
* submit a job to local runner
@@ -408,7 +408,7 @@ private String validateFiles(String files, Configuration conf)
// check if the file exists in this file system
// we need to recreate this filesystem object to copy
- // these files to the file system jobtracker is running
+ // these files to the file system ResourceManager is running
// on.
FileSystem fs = path.getFileSystem(conf);